==> vb-react-form-0.0.3.tgz: package/es/field.js <==
import _extends from 'babel-runtime/helpers/extends';
import _Promise from 'babel-runtime/core-js/promise';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import { getElementProps } from './utils';
import { FieldInput, FieldText, FieldRadio, FieldCheckbox, FieldSelect, FieldRadioGroup, FieldCheckboxGroup } from './fields';
import { FieldProps } from './field-props';
import { FieldAttr } from './field-attr';
import { isEqual } from 'lodash';

var Field = function (_React$Component) {
  _inherits(Field, _React$Component);

  function Field(props) {
    _classCallCheck(this, Field);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _this.onFocus = function (event) {
      var _this$props$onFocus = _this.props.onFocus,
          onFocus = _this$props$onFocus === undefined ? function () {} : _this$props$onFocus;

      _this.field.setFocus(true);
      _this.validateField(FieldAttr.events.FOCUS);
      onFocus(_this.field, event);
    };

    _this.onBlur = function (event) {
      var _this$props$onBlur = _this.props.onBlur,
          onBlur = _this$props$onBlur === undefined ? function () {} : _this$props$onBlur;

      _this.field.setFocus(false);
      _this.field.setTouched(true);
      _this.validateField(FieldAttr.events.BLUR);
      onBlur(_this.field, event);
    };

    _this.onChange = function (value, event) {
      var _this$props$onChange = _this.props.onChange,
          onChange = _this$props$onChange === undefined ? function () {} : _this$props$onChange;

      _this.field.setValue(value);
      _this.field.setTouched(true);
      _this.field.setDirty(true);
      _this.validateField(FieldAttr.events.CHANGE);
      _this.updateState();
      onChange(_this.field, event);
    };

    _this.validate = function () {
      var _this$props$onUpdate = _this.props.onUpdate,
          onUpdate = _this$props$onUpdate === undefined ? function () {} : _this$props$onUpdate;

      _this.field.setDirty(true);
      _this.validateField();
      onUpdate(_this.field);
    };

    _this.reset = function (value) {
      return new _Promise(function (resolve) {
        var _this$props$onInit = _this.props.onInit,
            onInit = _this$props$onInit === undefined ? function () {} : _this$props$onInit;

        _this.field = _this.createField({ value: value });
        _this.setState({
          value: _this.field.value
        }, function () {
          _this.validateField();
          onInit(_this.field);
          resolve(_this.field);
        });
      });
    };

    _this.updateState = function () {
      _this.setState({ value: _this.field.value });
    };

    _this.field = _this.createField();
    _this.validateField();
    _this.state = {
      value: _this.field.value
    };
    return _this;
  }

  Field.prototype.componentDidMount = function componentDidMount() {
    var _props$onInit = this.props.onInit,
        onInit = _props$onInit === undefined ? function () {} : _props$onInit;

    onInit(this.field);
  };

  Field.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var changed = false;
    var validate = false;
    if (this.props.value !== nextProps.value) {
      this.field.setValue(nextProps.value);
      this.updateState();
      changed = true;
      validate = true;
    }
    if (!isEqual(this.props.validators, nextProps.validators)) {
      this.field.setValidators(nextProps.validators);
      this.field.setValidatorsOptions(nextProps.validatorsOptions);
      changed = true;
      validate = true;
    }
    if (!isEqual(this.props.asyncValidator, nextProps.asyncValidator)) {
      this.field.setAsyncValidator(nextProps.asyncValidator);
      this.field.setAsyncValidatorOptions(nextProps.asyncValidatorOptions);
      changed = true;
      validate = true;
    }
    if (validate) {
      this.validateField();
    }
    if (changed) {
      var _nextProps$onUpdate = nextProps.onUpdate,
          onUpdate = _nextProps$onUpdate === undefined ? function () {} : _nextProps$onUpdate;

      onUpdate(this.field);
    }
  };

  Field.prototype.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState) {
    return !isEqual(this.props, nextProps) || !isEqual(this.state, nextState);
  };

  Field.prototype.componentWillUnmount = function componentWillUnmount() {
    var _props$onRemove = this.props.onRemove,
        onRemove = _props$onRemove === undefined ? function () {} : _props$onRemove;

    onRemove(this.field);
  };

  Field.prototype.createField = function createField() {
    var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var _props = this.props,
        name = _props.name,
        _props$value = _props.value,
        value = _props$value === undefined ? '' : _props$value,
        _props$validators = _props.validators,
        validators = _props$validators === undefined ? [] : _props$validators,
        _props$validatorsOpti = _props.validatorsOptions,
        validatorsOptions = _props$validatorsOpti === undefined ? {} : _props$validatorsOpti,
        _props$asyncValidator = _props.asyncValidator,
        asyncValidator = _props$asyncValidator === undefined ? null : _props$asyncValidator,
        _props$asyncValidator2 = _props.asyncValidatorOptions,
        asyncValidatorOptions = _props$asyncValidator2 === undefined ? {} : _props$asyncValidator2;

    var val = props.value !== undefined ? props.value : value; // For reset values
    return new FieldAttr(this, name, val, validators, validatorsOptions, asyncValidator, asyncValidatorOptions);
  };

  Field.prototype.validateField = function validateField(event) {
    var _this2 = this;

    var _props$onAsyncValid = this.props.onAsyncValid,
        onAsyncValid = _props$onAsyncValid === undefined ? function () {} : _props$onAsyncValid;

    this.field.validate();
    this.field.asyncValidate(event, function (active) {
      active && onAsyncValid(_this2.field);
    });
  };

  Field.prototype.render = function render() {
    // console.log(111111, this.props.name);
    var defaultComponent = FieldInput;
    var _props2 = this.props,
        component = _props2.component,
        type = _props2.type;
    var value = this.state.value;

    switch (type) {
      case 'checkbox':
        defaultComponent = FieldCheckbox;
        break;
      case 'radio':
        defaultComponent = FieldRadio;
        break;
    }
    return React.createElement(component || defaultComponent, _extends({}, getElementProps(this.props), {
      onFocus: this.onFocus,
      onBlur: this.onBlur,
      onChange: this.onChange,
      value: value
    }));
  };

  return Field;
}(React.Component);

Field.propTypes = _extends({}, FieldProps, {
  onInit: React.PropTypes.func,
  onUpdate: React.PropTypes.func,
  onAsyncValid: React.PropTypes.func
});

Field.Input = FieldInput;
Field.Radio = FieldRadio;
Field.Checkbox = FieldCheckbox;
Field.RadioGroup = FieldRadioGroup;
Field.CheckboxGroup = FieldCheckboxGroup;
Field.Select = FieldSelect;
Field.Text = FieldText;

export { Field };

==> vb-react-form-0.0.8.tgz: package/es/field.js <==
import _extends from 'babel-runtime/helpers/extends';
import _Promise from 'babel-runtime/core-js/promise';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import PropTypes from 'prop-types';
import { getElementProps } from './utils';
import { FieldInput, FieldText, FieldRadio, FieldCheckbox, FieldSelect, FieldRadioGroup, FieldCheckboxGroup } from './fields';
import { FieldProps } from './field-props';
import { FieldAttr } from './field-attr';
import { isEqual } from 'lodash';

var Field = function (_React$Component) {
  _inherits(Field, _React$Component);

  function Field(props) {
    _classCallCheck(this, Field);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _this.onFocus = function (event) {
      var _this$props$onFocus = _this.props.onFocus,
          onFocus = _this$props$onFocus === undefined ? function () {} : _this$props$onFocus;

      _this.field.setFocus(true);
      _this.validateField(FieldAttr.events.FOCUS);
      onFocus(_this.field, event);
    };

    _this.onBlur = function (event) {
      var _this$props$onBlur = _this.props.onBlur,
          onBlur = _this$props$onBlur === undefined ? function () {} : _this$props$onBlur;

      _this.field.setFocus(false);
      _this.field.setTouched(true);
      _this.validateField(FieldAttr.events.BLUR);
      onBlur(_this.field, event);
    };

    _this.onChange = function (value, event) {
      var _this$props$onChange = _this.props.onChange,
          onChange = _this$props$onChange === undefined ? function () {} : _this$props$onChange;

      _this.field.setValue(value);
      _this.field.setTouched(true);
      _this.field.setDirty(true);
      _this.validateField(FieldAttr.events.CHANGE);
      _this.updateState();
      onChange(_this.field, event);
    };

    _this.validate = function () {
      var _this$props$onUpdate = _this.props.onUpdate,
          onUpdate = _this$props$onUpdate === undefined ? function () {} : _this$props$onUpdate;

      _this.field.setDirty(true);
      _this.validateField();
      onUpdate(_this.field);
    };

    _this.reset = function (value) {
      return new _Promise(function (resolve) {
        var _this$props$onInit = _this.props.onInit,
            onInit = _this$props$onInit === undefined ? function () {} : _this$props$onInit;

        _this.field = _this.createField({ value: value });
        _this.setState({
          value: _this.field.value
        }, function () {
          _this.validateField();
          onInit(_this.field);
          resolve(_this.field);
        });
      });
    };

    _this.updateState = function () {
      _this.setState({ value: _this.field.value });
    };

    _this.field = _this.createField();
    _this.validateField();
    _this.state = {
      value: _this.field.value
    };
    return _this;
  }

  Field.prototype.componentDidMount = function componentDidMount() {
    var _props$onInit = this.props.onInit,
        onInit = _props$onInit === undefined ? function () {} : _props$onInit;

    onInit(this.field);
  };

  Field.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var changed = false;
    var validate = false;
    if (this.props.value !== nextProps.value) {
      this.field.setValue(nextProps.value);
      this.updateState();
      changed = true;
      validate = true;
    }
    if (!isEqual(this.props.validators, nextProps.validators)) {
      this.field.setValidators(nextProps.validators);
      this.field.setValidatorsOptions(nextProps.validatorsOptions);
      changed = true;
      validate = true;
    }
    if (!isEqual(this.props.asyncValidator, nextProps.asyncValidator)) {
      this.field.setAsyncValidator(nextProps.asyncValidator);
      this.field.setAsyncValidatorOptions(nextProps.asyncValidatorOptions);
      changed = true;
      validate = true;
    }
    if (validate) {
      this.validateField();
    }
    if (changed) {
      var _nextProps$onUpdate = nextProps.onUpdate,
          onUpdate = _nextProps$onUpdate === undefined ? function () {} : _nextProps$onUpdate;

      onUpdate(this.field);
    }
  };

  Field.prototype.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState) {
    return !isEqual(this.props, nextProps) || !isEqual(this.state, nextState);
  };

  Field.prototype.componentWillUnmount = function componentWillUnmount() {
    var _props$onRemove = this.props.onRemove,
        onRemove = _props$onRemove === undefined ? function () {} : _props$onRemove;

    onRemove(this.field);
  };

  Field.prototype.createField = function createField() {
    var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var _props = this.props,
        name = _props.name,
        _props$value = _props.value,
        value = _props$value === undefined ? '' : _props$value,
        _props$validators = _props.validators,
        validators = _props$validators === undefined ? [] : _props$validators,
        _props$validatorsOpti = _props.validatorsOptions,
        validatorsOptions = _props$validatorsOpti === undefined ? {} : _props$validatorsOpti,
        _props$asyncValidator = _props.asyncValidator,
        asyncValidator = _props$asyncValidator === undefined ? null : _props$asyncValidator,
        _props$asyncValidator2 = _props.asyncValidatorOptions,
        asyncValidatorOptions = _props$asyncValidator2 === undefined ? {} : _props$asyncValidator2;

    var val = props.value !== undefined ? props.value : value; // For reset values
    return new FieldAttr(this, name, val, validators, validatorsOptions, asyncValidator, asyncValidatorOptions);
  };

  Field.prototype.validateField = function validateField(event) {
    var _this2 = this;

    var _props$onAsyncValid = this.props.onAsyncValid,
        onAsyncValid = _props$onAsyncValid === undefined ? function () {} : _props$onAsyncValid;

    this.field.validate();
    this.field.asyncValidate(event, function (active) {
      active && onAsyncValid(_this2.field);
    });
  };

  Field.prototype.render = function render() {
    // console.log(111111, this.props.name);
    var defaultComponent = FieldInput;
    var _props2 = this.props,
        component = _props2.component,
        type = _props2.type;
    var value = this.state.value;

    switch (type) {
      case 'checkbox':
        defaultComponent = FieldCheckbox;
        break;
      case 'radio':
        defaultComponent = FieldRadio;
        break;
    }
    return React.createElement(component || defaultComponent, _extends({}, getElementProps(this.props), {
      onFocus: this.onFocus,
      onBlur: this.onBlur,
      onChange: this.onChange,
      value: value
    }));
  };

  return Field;
}(React.Component);

Field.propTypes = _extends({}, FieldProps, {
  onInit: PropTypes.func,
  onUpdate: PropTypes.func,
  onAsyncValid: PropTypes.func
});

Field.Input = FieldInput;
Field.Radio = FieldRadio;
Field.Checkbox = FieldCheckbox;
Field.RadioGroup = FieldRadioGroup;
Field.CheckboxGroup = FieldCheckboxGroup;
Field.Select = FieldSelect;
Field.Text = FieldText;

export { Field };
